
#ifndef __LIBGNOMENU_APPLICATION_H__
#define __LIBGNOMENU_APPLICATION_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libwnck/libwnck.h>
#include <gdk-pixbuf/gdk-pixdata.h>
#include <gtk/gtk.h>

G_BEGIN_DECLS


#define GNOMENU_TYPE_APPLICATION (gnomenu_application_get_type ())
#define GNOMENU_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOMENU_TYPE_APPLICATION, GnomenuApplication))
#define GNOMENU_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GNOMENU_TYPE_APPLICATION, GnomenuApplicationClass))
#define GNOMENU_IS_APPLICATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOMENU_TYPE_APPLICATION))
#define GNOMENU_IS_APPLICATION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GNOMENU_TYPE_APPLICATION))
#define GNOMENU_APPLICATION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GNOMENU_TYPE_APPLICATION, GnomenuApplicationClass))

typedef struct _GnomenuApplication GnomenuApplication;
typedef struct _GnomenuApplicationClass GnomenuApplicationClass;
typedef struct _GnomenuApplicationPrivate GnomenuApplicationPrivate;
typedef struct _GnomenuParamSpecApplication GnomenuParamSpecApplication;

/******
 * The binary executable name is used as the key to link 
 * Wnck with GMenu.
 *
 * If the bin exec starts with wine, mono, python, use
 * the application's full name. (Although usually app and
 * dists don't agree on the same name!)
 *
 * the policy is sub-opt, because
 * one executable can actually be multiple applications,
 *
 * Example: NXClient Openoffice
 *
 * Known problem: Openoffice suite apps always show up 
 * as one Openoffice app (the last found one in GMenu).
 * */
struct _GnomenuApplication {
	GTypeInstance parent_instance;
	volatile int ref_count;
	GnomenuApplicationPrivate * priv;
	GList* wnck_applications;
};

struct _GnomenuApplicationClass {
	GTypeClass parent_class;
	void (*finalize) (GnomenuApplication *self);
};

struct _GnomenuParamSpecApplication {
	GParamSpec parent_instance;
};


extern GList* gnomenu_application_applications;
extern GHashTable* gnomenu_application_dict;
void gnomenu_application_init (void);
GnomenuApplication* gnomenu_application_add_application (const char* key);
GnomenuApplication* gnomenu_application_lookup (const char* key);
GnomenuApplication* gnomenu_application_lookup_from_wnck (WnckApplication* wapp);
void gnomenu_application_update (GnomenuApplication* self);
char* get_task_name_by_pid (gint pid);
const char* gnomenu_application_get_readable_name (GnomenuApplication* self);
const char* gnomenu_application_get_exec_path (GnomenuApplication* self);
const char* gnomenu_application_get_icon_name (GnomenuApplication* self);
GdkPixbuf* gnomenu_application_get_icon_pixbuf (GnomenuApplication* self);
gboolean gnomenu_application_get_not_in_menu (GnomenuApplication* self);
GtkWidget* gnomenu_application_get_proxy_item (GnomenuApplication* self);
GParamSpec* gnomenu_param_spec_application (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
gpointer gnomenu_value_get_application (const GValue* value);
void gnomenu_value_set_application (GValue* value, gpointer v_object);
GType gnomenu_application_get_type (void);
gpointer gnomenu_application_ref (gpointer instance);
void gnomenu_application_unref (gpointer instance);


G_END_DECLS

#endif
