
#ifndef __LIBGNOMENU_INTERFACE_ITEM_H__
#define __LIBGNOMENU_INTERFACE_ITEM_H__

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <libgnomenu/interface-shell.h>

G_BEGIN_DECLS


#define GNOMENU_TYPE_ITEM_TYPE (gnomenu_item_type_get_type ())

#define GNOMENU_TYPE_ITEM_STATE (gnomenu_item_state_get_type ())

#define GNOMENU_TYPE_ITEM (gnomenu_item_get_type ())
#define GNOMENU_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GNOMENU_TYPE_ITEM, GnomenuItem))
#define GNOMENU_IS_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GNOMENU_TYPE_ITEM))
#define GNOMENU_ITEM_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GNOMENU_TYPE_ITEM, GnomenuItemIface))


typedef enum  {
	GNOMENU_ITEM_TYPE_NORMAL = 0,
	GNOMENU_ITEM_TYPE_CHECK = 1,
	GNOMENU_ITEM_TYPE_RADIO = 2,
	GNOMENU_ITEM_TYPE_IMAGE = 3,
	GNOMENU_ITEM_TYPE_SEPARATOR = 4,
	GNOMENU_ITEM_TYPE_ARROW = 5,
	GNOMENU_ITEM_TYPE_ICON = 6
} GnomenuItemType;

typedef enum  {
	GNOMENU_ITEM_STATE_UNTOGGLED = 0,
	GNOMENU_ITEM_STATE_TOGGLED = 1,
	GNOMENU_ITEM_STATE_TRISTATE = 2
} GnomenuItemState;

struct _GnomenuItemIface {
	GTypeInterface parent_iface;
	GnomenuShell* (*get_shell) (GnomenuItem* self);
	GnomenuShell* (*get_sub_shell) (GnomenuItem* self);
	gboolean (*get_has_sub_shell) (GnomenuItem* self);
	void (*set_has_sub_shell) (GnomenuItem* self, gboolean value);
	gboolean (*get_client_side_sub_shell) (GnomenuItem* self);
	void (*set_client_side_sub_shell) (GnomenuItem* self, gboolean value);
	char* (*get_item_id) (GnomenuItem* self);
	void (*set_item_id) (GnomenuItem* self, const char* value);
	GnomenuItemType (*get_item_type) (GnomenuItem* self);
	void (*set_item_type) (GnomenuItem* self, GnomenuItemType value);
	gboolean (*get_item_use_underline) (GnomenuItem* self);
	void (*set_item_use_underline) (GnomenuItem* self, gboolean value);
	gboolean (*get_item_sensitive) (GnomenuItem* self);
	void (*set_item_sensitive) (GnomenuItem* self, gboolean value);
	gboolean (*get_item_visible) (GnomenuItem* self);
	void (*set_item_visible) (GnomenuItem* self, gboolean value);
	GnomenuItemState (*get_item_state) (GnomenuItem* self);
	void (*set_item_state) (GnomenuItem* self, GnomenuItemState value);
	char* (*get_item_label) (GnomenuItem* self);
	void (*set_item_label) (GnomenuItem* self, const char* value);
	char* (*get_item_icon) (GnomenuItem* self);
	void (*set_item_icon) (GnomenuItem* self, const char* value);
	char* (*get_item_accel_text) (GnomenuItem* self);
	void (*set_item_accel_text) (GnomenuItem* self, const char* value);
	char* (*get_item_font) (GnomenuItem* self);
	void (*set_item_font) (GnomenuItem* self, const char* value);
};


GType gnomenu_item_type_get_type (void);
GType gnomenu_item_state_get_type (void);
gboolean gnomenu_item_is_child_of (GnomenuItem* self, GnomenuItem* possible_parent);
GnomenuItemState gnomenu_item_state_from_string (const char* str);
const char* gnomenu_item_state_to_string (GnomenuItemState state);
GnomenuItemType gnomenu_item_type_from_string (const char* str);
gboolean gnomenu_item_type_has_label (GnomenuItemType type);
const char* gnomenu_item_type_to_string (GnomenuItemType type);
GnomenuShell* gnomenu_item_get_shell (GnomenuItem* self);
GnomenuShell* gnomenu_item_get_sub_shell (GnomenuItem* self);
gboolean gnomenu_item_get_has_sub_shell (GnomenuItem* self);
void gnomenu_item_set_has_sub_shell (GnomenuItem* self, gboolean value);
gboolean gnomenu_item_get_client_side_sub_shell (GnomenuItem* self);
void gnomenu_item_set_client_side_sub_shell (GnomenuItem* self, gboolean value);
GnomenuShell* gnomenu_item_get_toplevel_shell (GnomenuItem* self);
gint gnomenu_item_get_item_position (GnomenuItem* self);
char* gnomenu_item_get_item_id (GnomenuItem* self);
void gnomenu_item_set_item_id (GnomenuItem* self, const char* value);
GnomenuItemType gnomenu_item_get_item_type (GnomenuItem* self);
void gnomenu_item_set_item_type (GnomenuItem* self, GnomenuItemType value);
gboolean gnomenu_item_get_item_use_underline (GnomenuItem* self);
void gnomenu_item_set_item_use_underline (GnomenuItem* self, gboolean value);
gboolean gnomenu_item_get_item_sensitive (GnomenuItem* self);
void gnomenu_item_set_item_sensitive (GnomenuItem* self, gboolean value);
gboolean gnomenu_item_get_item_visible (GnomenuItem* self);
void gnomenu_item_set_item_visible (GnomenuItem* self, gboolean value);
GnomenuItemState gnomenu_item_get_item_state (GnomenuItem* self);
void gnomenu_item_set_item_state (GnomenuItem* self, GnomenuItemState value);
char* gnomenu_item_get_item_label (GnomenuItem* self);
void gnomenu_item_set_item_label (GnomenuItem* self, const char* value);
char* gnomenu_item_get_item_icon (GnomenuItem* self);
void gnomenu_item_set_item_icon (GnomenuItem* self, const char* value);
char* gnomenu_item_get_item_accel_text (GnomenuItem* self);
void gnomenu_item_set_item_accel_text (GnomenuItem* self, const char* value);
char* gnomenu_item_get_item_font (GnomenuItem* self);
void gnomenu_item_set_item_font (GnomenuItem* self, const char* value);
char* gnomenu_item_get_item_path_name (GnomenuItem* self);
char* gnomenu_item_get_item_path (GnomenuItem* self);
GType gnomenu_item_get_type (void);


G_END_DECLS

#endif
